package com.jz.common.utils;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class StringUtils {

	/**
	 * <p>
	 * Checks if a CharSequence is whitespace, empty ("") or null.
	 * </p>
	 *
	 * <pre>
	 * StringUtils.isBlank(null)      = true
	 * StringUtils.isBlank("")        = true
	 * StringUtils.isBlank(" ")       = true
	 * StringUtils.isBlank("bob")     = false
	 * StringUtils.isBlank("  bob  ") = false
	 * </pre>
	 *
	 * @param cs
	 *            the CharSequence to check, may be null
	 * @return {@code true} if the CharSequence is null, empty or whitespace
	 * @since 2.0
	 * @since 3.0 Changed signature from isBlank(String) to isBlank(CharSequence)
	 */
	public static boolean isBlank(final CharSequence cs) {
		int strLen;
		if (cs == null || (strLen = cs.length()) == 0) {
			return true;
		}
		for (int i = 0; i < strLen; i++) {
			if (Character.isWhitespace(cs.charAt(i)) == false) {
				return false;
			}
		}
		return true;
	}

	public static boolean isNotBlank(final CharSequence cs) {
		return !isBlank(cs);
	}

	public static String nvl(String sIn) {
		return (sIn == null || "null".equals(sIn)) ? "" : sIn;
	}

	public static String nvl(Object sIn) {
		return (sIn == null || "null".equals(sIn)) ? "" : sIn.toString();
	}

	public static String nvl(String sIn, String defaultStr) {
		return (sIn == null || "null".equals(sIn)) ? defaultStr : sIn;
	}

	public static boolean hasLength(String str) {
		return (str != null && str.length() > 0);
	}

	public static boolean isMobile(String str) {
		if (!hasText(str)) {
			return false;
		}
		Pattern p = null;
		Matcher m = null;
		boolean b = false;
		p = Pattern.compile("^[1][3,4,5,7,8][0-9]{9}$"); // 验证手机号
		m = p.matcher(str);
		b = m.matches();
		return b;
	}

	public static boolean hasText(String str) {
		if (!hasLength(str)) {
			return false;
		}
		int strLen = str.length();
		for (int i = 0; i < strLen; i++) {
			if (!Character.isWhitespace(str.charAt(i))) {
				return true;
			}
		}
		return false;
	}

	public static boolean isNull(String str) {
		return str == null || str.isEmpty();
	}

	public static boolean isNotNull(String str) {
		return !isNull(str);
	}

	// Empty checks
	// -----------------------------------------------------------------------
	/**
	 * <p>
	 * Checks if a CharSequence is empty ("") or null.
	 * </p>
	 *
	 * <pre>
	 * StringUtils.isEmpty(null)      = true
	 * StringUtils.isEmpty("")        = true
	 * StringUtils.isEmpty(" ")       = false
	 * StringUtils.isEmpty("bob")     = false
	 * StringUtils.isEmpty("  bob  ") = false
	 * </pre>
	 *
	 * <p>
	 * NOTE: This method changed in Lang version 2.0. It no longer trims the
	 * CharSequence. That functionality is available in isBlank().
	 * </p>
	 *
	 * @param cs
	 *            the CharSequence to check, may be null
	 * @return {@code true} if the CharSequence is empty or null
	 * @since 3.0 Changed signature from isEmpty(String) to isEmpty(CharSequence)
	 */
	public static boolean isEmpty(final CharSequence cs) {
		return cs == null || cs.length() == 0;
	}

	/** 获取对象字符值，空白字符串将返回默认值 */
	public static String getStringValue(Object object, String defaultValue) {
		if (object == null || object.toString().trim().equals("")) {
			return defaultValue;
		} else {
			return object.toString();
		}
	}

	public static boolean isNumeric(String str) {
		Pattern pattern = Pattern.compile("^\\d+$");
		Matcher isNum = pattern.matcher(str);
		if (!isNum.matches()) {
			return false;
		}
		return true;
	}

	public static String toString(Object obj) {
		if (obj == null)
			return "";

		return obj.toString();
	}

	public static String toTrimString(String str) {
		return toString(str).trim();
	}

	public static String toString(String[] s) {
		if (s == null)
			return "";

		StringBuffer sb = new StringBuffer();
		for (int i = 0; i < s.length; ++i)
			sb.append(s[i] + ((i < s.length - 1) ? "," : ""));

		return sb.toString();
	}

	public static String byteToString(byte[] b) {
		String temp = "";
		for (int i = 0; i < b.length; ++i)
			temp = temp + new Byte(b[i]).toString() + ";";

		return temp;
	}

	public static byte[] stringtobyte(String s) {
		String[] temp = s.split(";");
		byte[] b = new byte[temp.length];
		for (int i = 0; i < temp.length; ++i)
			b[i] = new Byte(temp[i]).byteValue();

		return b;
	}

	public static boolean sql_inj(String str)

	{

		 String inj_str = "'|and|exec|insert|select|delete|update|count|*|%|chr|mid|master|truncate|char|declare|;|or |-|+|,";
				     String inj_stra[] =inj_str.split("\\|");
				     for (int i=0 ; i < inj_stra.length ; i++ )
				     {
				         if (str.indexOf(inj_stra[i])>=0)
				         {
				             return true;
				         }
				     }


		return false;

	}
	
}
