package com.jz.dmp.modules.service;

import com.jz.common.constant.JsonResult;
import com.jz.dmp.modules.controller.dataService.bean.*;

import java.util.Map;

/**
 * @ClassName: DmpApiMangeService
 * @Description: 数据服务Api管理
 * @Author: Bellamy
 * @Date 2021/1/18
 * @Version 1.0
 */
public interface DmpApiMangeService {

    /**
     * 授权给他人的API-列表分页查询
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    JsonResult queryApiAuthListPage(AuthListInfoReq req) throws Exception;

    /**
     * 取消授权
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    JsonResult cancelApiAuth(String id) throws Exception;

    /**
     * 发布的API-API列表分页查询
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    JsonResult queryApiListPage(ApiInterfaceInfoListReq req) throws Exception;

    /**
     * 删除api
     *
     * @author Bellamy
     * @since 2021-01-18
     */
    JsonResult delApiInfo(String apiKey, String type) throws Exception;

    /**
     * 根据apiid获取API详情
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    JsonResult queryApiInfoByApiId(String id) throws Exception;

    /**
     * 授权给组织-提交保存
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    JsonResult addApiAuthToOrg(AuthUserApiReq req) throws Exception;

    /**
     * API测试
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    JsonResult apiTestInfo(Map<String,String> params) throws Exception;

    /**
     * 查看日志
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    JsonResult checkApiLogInfo(LogInfoListReq req) throws Exception;

    /**
     * 授权模糊查询组织信息
     *
     * @author Bellamy
     * @since 2021-01-19
     */
    JsonResult getAuthOrgList(String key) throws Exception;

    /**
     * @Description:服务发布/服务取消
     * @author Bellamy
     * @since 2021-02-07
     */
    JsonResult apiPublishCancel(String id, Boolean optStatus) throws Exception;

    /**
     * 盐值重置
     *
     * @author Bellamy
     * @since 2021-02-20
     */
    JsonResult saltReset(SaltResetReq req) throws Exception;

    /**
     * 授权管理-api列表
     *
     * @author Bellamy
     * @since 2021-02-20
     */
    JsonResult queryAuthApiList(AuthApiListReq req) throws Exception;

    /**
     * 用户授权
     *
     * @author Bellamy
     * @since 2021-02-20
     */
    JsonResult authUserApi(AuthUserApiReq req) throws Exception;

    /**
     * 服务开发--上传（发送给数据银行）
     *
     * @author Bellamy
     * @since 2021-02-20
     */
    JsonResult serverUpload(String id) throws Exception;

    /**
     * 日志详情
     *
     * @author Bellamy
     * @since 2021-02-20
     */
    JsonResult logDetails(String id) throws Exception;

    /**
     * 授权--组织名称查询
     *
     * @author Bellamy
     * @since 2021-03-02
     */
    JsonResult getAuthOrgName(String orgName, String projectId) throws Exception;

    /**
     * API测试--下拉框
     *
     * @author Bellamy
     * @since 2021-03-03
     */
    JsonResult getApiTestGetApiKey(String apiName) throws Exception;
}
